@@ -20,6 +20,7 @@ from .base import (
     ListComp,
     NaiveConversion,
     Not,
+    OptionalCollectionItem,
     Or,
     Set,
     SetComp,
@@ -28,6 +29,7 @@ from .base import (
     ensure_conversion,
 )
 from .joins import _JoinConditions, join
+from .mutations import Mutations
 
 
 __all__ = ["conversion"]
@@ -61,6 +63,7 @@ class _Conversion:
     tuple = Tuple
     set = Set
     dict = Dict
+    optional = OptionalCollectionItem
 
     list_comp = ListComp
     tuple_comp = TupleComp
@@ -76,6 +79,8 @@ class _Conversion:
     LEFT = _JoinConditions.LEFT
     RIGHT = _JoinConditions.RIGHT
 
+    Mut = Mutations
+
     def __call__(self, obj: object):
         """Shortcut for ``ensure_conversion``"""
         return ensure_conversion(obj)
